@@ -11,7 +11,8 @@ $SIG{__DIE__} = \&Carp::confess;
 
 
 use vars qw($VERSION);
-$VERSION = '4.006'; # $Id: //depot/Tkutf8/Tk/MakeDepend.pm#6 $
+#$VERSION = sprintf '4.%03d', q$Revision: #13 $ =~ /\D(\d+)\s*$/;
+$VERSION = '4.014';
 
 sub scan_file;
 
@@ -41,10 +42,10 @@ sub term
 {
  remove_comment();
  return !term() if s/^\s*!//;
- return exists($define{$1}) if s/^\s*defined\s*\(([_A-Za-z][_\w]*)\)//;
+ return exists($define{$1}) if s/^\s*defined\s*\(([_A-Za-z][_\w]*)\s*\)//;
  return exists($define{$1}) if s/^\s*defined\s*([_A-Za-z][_\w]*)//;
- return eval "$1" if s/^\s*(0x[0-9a-f]+)//i;
- return $1 if s/^\s*(\d+)//;
+ return eval "$1" if s/^\s*(0x[0-9a-f]+)L?//i;
+ return $1 if s/^\s*(\d+)L?//;
  return $define{$1} || 0 if s/^\s*([_A-Za-z][_\w]*)//;
  if (s/^\s*\(//)
   {
@@ -64,7 +65,7 @@ my %pri = ( '&&' => 4,
 sub expression
 {
  my $pri = shift;
- #printf STDERR "%d# expr . $_\n";
+ # printf STDERR "%d# expr . $_\n";
  my $invert = 0;
  my $lhs = term() || 0;
  remove_comment();
@@ -102,7 +103,7 @@ sub do_if
    local $_ = $expr;
    my $val = expression(0) != 0;
    warn "trailing: $_" if /\S/;
-   #printf STDERR "%d from $key $expr\n",$val; 
+   #printf STDERR "%d from $key $expr\n",$val;
    return $val;
   }
 }
@@ -201,77 +202,141 @@ sub scan_file
   }
 }
 
-sub reset_includes
-{
- undef @include;
- push @include, $Config{'usrinc'}
-   if (defined $Config{'usrinc'} and $Config{'usrinc'} ne '');
-}
-
 sub command_line
 {
- reset_includes();
- my %def = ('__STDC__' => 1 );
+ @include = ();
+ local %define = ('__STDC__' => 1 );
  my $data = '';
- while (@_)
+ my @files;
+ while (@_ && $_[-1] !~ /^-/)
   {
-   $_ = shift(@_);
+   unshift(@files,pop(@_));
+  }
+ my $flags = $Config{ccflags};
+ $flags =~ s/^\s+|\s+$//g;
+ my @opt = (@_, split(/\s+/,$flags));
+ while (@opt)
+  {
+   local $_ = shift(@opt);
    if (/^-I(.*)$/)
     {
-     # force /usr/include to be last element of @include
-     if (@include)
-      {
-       splice @include, $#include, 0, $1;
-      }
-     else
-      {
-       @include = ($1);
-      }
+     push @include,$1;
     }
    elsif (/^-D([^=]+)(?:=(.*))?$/)
     {
-     $def{$1} = $2 || 1;
+     $define{$1} = $2 || 1;
     }
    elsif (/^-U(.*)$/)
     {
-     delete $def{$1};
+     delete $define{$1};
     }
    elsif (/^(-.*)$/)
     {
+     # Some option
+     if ($opt[0] !~ /^-/)
+      {
+       # next arg does not start with '-' assume it
+       # belongs to this option and discard it silently
+       shift(@opt);
+      }
+    }
+   else
+    {
+     # We got confused
      warn "Ignoring $1\n";
     }
-   elsif (/^(.*)\.[^\.]+$/)
+  }
+ # force /usr/include (and other system directories) to be last element of @include
+ if ($Config{ccname} eq 'gcc')
+  {
+   push @include, parse_gcc_inc_search_list();
+  }
+ else
+  {
+   push @include, $Config{'usrinc'}
+     if (defined $Config{'usrinc'} and $Config{'usrinc'} ne '');
+  }
+ # warn "Include:@include\n";
+ while (@files)
+  {
+   local $_ = shift(@files);
+   unless (/^(.*)\.[^\.]+$/)
     {
-     local %define = %def;
-     my $base = $1;
-     my $file = $_;
-     my %dep;
-     warn "Finding dependancies for $file\n";
-     scan_file($_,\%dep);
-     my $str = "\n$base\$(OBJ_EXT) : $base.c";
-     delete $dep{$file};
-     my @dep = (sort(keys %dep));
-     while (@dep)
-      {
-       my $dep = shift(@dep);
-       $dep =~ s#^\./##;
-       if (length($str)+length($dep) > 70)
-        {
-         $data .= "$str \\\n";
-         $str = ' ';
-        }
-       else
-        {
-         $str .= ' ';
-        }
-       $str .= $dep;
-      }
-     $data .= "$str\n";
+     warn "Skip $_";
+     next;
     }
+   local %define = %define;
+   my $base = $1;
+   my $file = $_;
+   my %dep;
+   warn "Finding dependencies for $file\n";
+   scan_file($_,\%dep);
+   my $str = "\n$base\$(OBJ_EXT) : $base.c";
+   delete $dep{$file};
+   my @dep = (sort(keys %dep));
+   while (@dep)
+    {
+     my $dep = shift(@dep);
+     $dep =~ s#^\./##;
+     if (length($str)+length($dep) > 70)
+      {
+       $data .= "$str \\\n";
+       $str = ' ';
+      }
+     else
+      {
+       $str .= ' ';
+      }
+     $str .= $dep;
+    }
+   $data .= "$str\n";
   }
  return $data;
 }
 
+sub parse_gcc_inc_search_list
+{
+ our @GCC_INC_SEARCH_LIST;
+ return @GCC_INC_SEARCH_LIST if @GCC_INC_SEARCH_LIST;
+
+ require File::Spec;
+ my $cmd = "$Config{cc} -xc -E -v -";
+ my @inc;
+ eval
+  {
+   open my $fh, "-|", "$cmd 2>&1 <".File::Spec->devnull
+     or die "Error while running $cmd: $!";
+
+   my $in_search_list;
+   while(<$fh>)
+    {
+     if (/^#include <\.\.\.> search starts here:/)
+      {
+       $in_search_list = 1;
+      }
+     elsif ($in_search_list)
+      {
+       last if /^End of search list/;
+       chomp;
+       s/^\s+//;
+       push @inc, $_;
+      }
+    }
+  };
+ if ($@)
+  {
+   warn $@;
+  }
+ if (!@inc)
+  {
+   # Fallback: add /usr/include
+   @inc = $Config{'usrinc'}
+     if (defined $Config{'usrinc'} and $Config{'usrinc'} ne '');
+  }
+ @GCC_INC_SEARCH_LIST = @inc;
+ @inc;
+}
+
 1;
 __END__
 
