@@ -5,9 +5,8 @@ package Tk::Table;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '4.013'; # was: sprintf '4.%03d', q$Revision: #12 $ =~ /\D(\d+)\s*$/;
+$VERSION = '4.015'; # was: sprintf '4.%03d', q$Revision: #12 $ =~ /\D(\d+)\s*$/;
 
-use Tk::Pretty;
 use AutoLoader;
 use base qw(Tk::Frame);
 
@@ -170,6 +169,7 @@ sub Layout
   {
    $t->{xsb} = $t->Scrollbar(-orient => 'horizontal', -command => ['xview' => $t]) unless (defined $t->{xsb});
    $xsb   = $t->{xsb};
+   $t->Advertise('xscrollbar' => $xsb);
    $xs[3] = $xsb->ReqHeight;
    if ($sb =~ /n/)
     {
@@ -191,6 +191,7 @@ sub Layout
   {
    $t->{ysb} = $t->Scrollbar(-orient => 'vertical', -command => ['yview' => $t]) unless (defined $t->{ysb});
    $ysb    = $t->{ysb};
+   $t->Advertise('yscrollbar' => $ysb);
    $ys[2]  = $ysb->ReqWidth;
    if ($sb =~ /w/)
     {
@@ -391,8 +392,8 @@ sub clear {
     my $self = shift;
     my $rows = $self->cget(-rows);
     my $cols = $self->cget(-columns);
-    foreach my $r (1 .. $rows) {
-	foreach my $c (1 .. $cols) {
+    foreach my $r (0 .. $rows-1) {
+	foreach my $c (0 .. $cols-1) {
 	    my $old = $self->get( $r, $c );
 	    next unless $old;
 	    $self->LostSlave($old);
